Package 'barry'

Title: Your Go-to Motif Accountant
Description: Provides the 'C++' header-only library 'barry' for use in R packages. 'barry' is a 'C++' template library for counting sufficient statistics on binary arrays and building discrete exponential-family models. It provides tools for sparse arrays, user-defined count statistics, support set constraints, power set generation, and includes modules for Discrete Exponential Family Models (DEFMs) and network statistics. By placing these headers in this package, we offer an efficient distribution system for CRAN as replication of this code in the sources of other packages is avoided. This package follows the same approach as the 'BH' package which provides 'Boost' headers for R packages.
Authors: George Vega Yon [aut, cre] (ORCID: <https://orcid.org/0000-0002-3171-0844>), U.S. Army Medical Research Acquisition Activity [fnd] (ORION project, Award #W81XWH1910615), National Cancer Institute [fnd] (IMAGE project, Grant #1P01CA196596)
Maintainer: George Vega Yon <[email protected]>
License: MIT + file LICENSE
Version: 0.2.1
Built: 2026-05-08 07:18:14 UTC
Source: https://github.com/uscbiostats/barryr

Help Index